@@ -30,6 +30,12 @@
 #include "oxygentabdemowidget.h"
 
 #include <gdk/gdkkeysyms.h>
+
+// Older (such as 2.20.1) GTK versions had different name for this
+#ifndef GDK_KEY_Q
+#define GDK_KEY_Q GDK_Q
+#endif
+
 #include <iostream>
 #include <sstream>
 
@@ -43,18 +49,18 @@ namespace Oxygen
         // create main widget
         _mainWidget = gtk_window_new( GTK_WINDOW_TOPLEVEL );
         gtk_window_set_default_size( GTK_WINDOW( _mainWidget ), 630, 500 );
-        gtk_window_set_title( GTK_WINDOW( _mainWidget ), "Oxygen-gtk Demo" );
+        gtk_window_set_title( GTK_WINDOW( _mainWidget ), "Oxygen-gtk3 Demo" );
         gtk_container_set_border_width( GTK_CONTAINER( _mainWidget ), 10 );
 
         // vertical container
-        GtkWidget* vbox( gtk_vbox_new( false, 5 ) );
+        GtkWidget* vbox( gtk_box_new( GTK_ORIENTATION_VERTICAL, 5 ) );
         gtk_container_add( GTK_CONTAINER( _mainWidget ), vbox );
         gtk_widget_show( vbox );
 
         GtkWidget* iconView(0L);
         {
             // first horizontal container
-            GtkWidget* hbox( gtk_hbox_new( false, 8 ) );
+            GtkWidget* hbox( gtk_box_new( GTK_ORIENTATION_HORIZONTAL, 8 ) );
             gtk_box_pack_start( GTK_BOX( vbox ), hbox, true, true, 0 );
             gtk_widget_show( hbox );
 
@@ -117,7 +123,7 @@ namespace Oxygen
 
         {
             // statusbar
-            GtkWidget* statusBar( gtk_hbox_new( false, 2 ) );
+            GtkWidget* statusBar( gtk_box_new( GTK_ORIENTATION_HORIZONTAL, 2 ) );
             gtk_box_pack_start( GTK_BOX( vbox ), statusBar, false, true, 0 );
             gtk_widget_show( statusBar );
 
@@ -230,7 +236,7 @@ namespace Oxygen
 
         // update window title
         std::ostringstream what;
-        what << widget->name() << " - Oxygen-gtk Demo";
+        what << widget->name() << " - Oxygen-gtk3 Demo";
         gtk_window_set_title( GTK_WINDOW( dialog._mainWidget ), what.str().c_str() );
     }
 
