@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 *
 * based on the Null Theme Engine for Gtk+.
 * Copyright (c) 2008 Robert Staudinger <robert.staudinger@gmail.com>
@@ -34,7 +34,7 @@ namespace Oxygen
     {
 
         // main widget
-        GtkWidget* mainWidget( gtk_vbox_new( false, 0 ) );
+        GtkWidget* mainWidget( gtk_box_new( GTK_ORIENTATION_VERTICAL, 0 ) );
         gtk_box_set_spacing( GTK_BOX( mainWidget ), 5 );
         setWidget( mainWidget );
 
@@ -82,7 +82,6 @@ namespace Oxygen
             gtk_scrolled_window_set_shadow_type( GTK_SCROLLED_WINDOW( scrolledWindow ), GTK_SHADOW_IN );
             gtk_scrolled_window_set_policy( GTK_SCROLLED_WINDOW( scrolledWindow ), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
             gtk_container_add( GTK_CONTAINER( scrolledWindow ), treeView );
-            gtk_container_set_border_width( GTK_CONTAINER( scrolledWindow ), 2 );
             gtk_widget_show( scrolledWindow );
 
             gtk_paned_pack1( GTK_PANED( vpaned ), scrolledWindow, true, true );
@@ -171,7 +170,6 @@ namespace Oxygen
             gtk_scrolled_window_set_shadow_type( GTK_SCROLLED_WINDOW( scrolledWindow ), GTK_SHADOW_IN );
             gtk_scrolled_window_set_policy( GTK_SCROLLED_WINDOW( scrolledWindow ), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
             gtk_container_add( GTK_CONTAINER( scrolledWindow ), treeView );
-            gtk_container_set_border_width( GTK_CONTAINER( scrolledWindow ), 2 );
             gtk_widget_show( scrolledWindow );
 
             gtk_paned_pack2( GTK_PANED( vpaned ), scrolledWindow, true, true );
