@@ -34,7 +34,7 @@ namespace Oxygen
     {
 
         // main widget
-        GtkWidget* mainWidget( gtk_hbox_new( false, 0 ) );
+        GtkWidget* mainWidget( gtk_box_new( GTK_ORIENTATION_HORIZONTAL, 0 ) );
         gtk_box_set_spacing( GTK_BOX( mainWidget ), 5 );
         setWidget( mainWidget );
 
@@ -53,15 +53,16 @@ namespace Oxygen
             gtk_widget_show( frame );
 
             // container
-            GtkWidget* box( gtk_vbox_new( false, 0 ) );
+            GtkWidget* box( gtk_box_new( GTK_ORIENTATION_VERTICAL, 0 ) );
             gtk_container_set_border_width( GTK_CONTAINER( box ), 5 );
             gtk_box_set_spacing( GTK_BOX( box ), 2 );
             gtk_widget_show( box );
             gtk_container_add( GTK_CONTAINER( frame ), box );
 
             // scale
-            _horizontalSliders._scale = gtk_hscale_new_with_range( 0, 100, 1 );
+            _horizontalSliders._scale = gtk_scale_new_with_range( GTK_ORIENTATION_HORIZONTAL, 0, 100, 1 );
             gtk_scale_set_draw_value( GTK_SCALE( _horizontalSliders._scale ), false );
+            gtk_range_set_value( GTK_RANGE( _horizontalSliders._scale ), 25 );
             gtk_box_pack_start( GTK_BOX( box ), _horizontalSliders._scale, false, true, 0 );
             gtk_widget_show( _horizontalSliders._scale );
 
@@ -81,7 +82,7 @@ namespace Oxygen
             gtk_progress_bar_set_orientation( GTK_PROGRESS_BAR( _horizontalSliders._progressBar ), GTK_PROGRESS_LEFT_TO_RIGHT );
             #endif
 
-            gtk_progress_set_show_text( GTK_PROGRESS( _horizontalSliders._progressBar ), true );
+            gtk_progress_bar_set_fraction( GTK_PROGRESS_BAR( _horizontalSliders._progressBar ), 0.25 );
             gtk_box_pack_start( GTK_BOX( box ), _horizontalSliders._progressBar, false, true, 0 );
             gtk_widget_show( _horizontalSliders._progressBar );
 
@@ -99,7 +100,7 @@ namespace Oxygen
 
             // scrollbar
             GtkAdjustment* adjustment( GTK_ADJUSTMENT( gtk_adjustment_new( 25, 0, 110, 1, 1, 10 ) ) );
-            _horizontalSliders._scrollBar = gtk_hscrollbar_new( adjustment );
+            _horizontalSliders._scrollBar = gtk_scrollbar_new( GTK_ORIENTATION_HORIZONTAL, adjustment );
             gtk_box_pack_start( GTK_BOX( box ), _horizontalSliders._scrollBar, false, true, 0 );
             gtk_widget_show( _horizontalSliders._scrollBar );
 
@@ -114,15 +115,16 @@ namespace Oxygen
             gtk_widget_show( frame );
 
             // container
-            GtkWidget* box( gtk_hbox_new( false, 0 ) );
+            GtkWidget* box( gtk_box_new( GTK_ORIENTATION_HORIZONTAL, 0 ) );
             gtk_container_set_border_width( GTK_CONTAINER( box ), 5 );
             gtk_box_set_spacing( GTK_BOX( box ), 5 );
             gtk_widget_show( box );
             gtk_container_add( GTK_CONTAINER( frame ), box );
 
             // scale
-            _verticalSliders._scale = gtk_vscale_new_with_range( 0, 100, 1 );
+            _verticalSliders._scale = gtk_scale_new_with_range( GTK_ORIENTATION_VERTICAL, 0, 100, 1 );
             gtk_scale_set_draw_value( GTK_SCALE( _verticalSliders._scale ), false );
+            gtk_range_set_value( GTK_RANGE( _verticalSliders._scale ), 25 );
             gtk_box_pack_start( GTK_BOX( box ), _verticalSliders._scale, false, true, 0 );
             gtk_widget_show( _verticalSliders._scale );
 
@@ -134,13 +136,14 @@ namespace Oxygen
             gtk_progress_bar_set_orientation( GTK_PROGRESS_BAR( _verticalSliders._progressBar ), GTK_PROGRESS_BOTTOM_TO_TOP );
             #endif
 
-            gtk_progress_set_show_text( GTK_PROGRESS( _verticalSliders._progressBar ), true );
+            // gtk_progress_set_show_text( GTK_PROGRESS( _verticalSliders._progressBar ), true );
+            gtk_progress_bar_set_fraction( GTK_PROGRESS_BAR( _verticalSliders._progressBar ), 0.25 );
             gtk_box_pack_start( GTK_BOX( box ), _verticalSliders._progressBar, false, true, 0 );
             gtk_widget_show( _verticalSliders._progressBar );
 
             // scrollbar
             GtkAdjustment* adjustment( GTK_ADJUSTMENT( gtk_adjustment_new( 25, 0, 110, 1, 1, 10 ) ) );
-            _verticalSliders._scrollBar = gtk_vscrollbar_new( adjustment );
+            _verticalSliders._scrollBar = gtk_scrollbar_new( GTK_ORIENTATION_VERTICAL, adjustment );
             gtk_box_pack_start( GTK_BOX( box ), _verticalSliders._scrollBar, false, true, 0 );
             gtk_widget_show( _verticalSliders._scrollBar );
 
@@ -149,8 +152,6 @@ namespace Oxygen
         _horizontalSliders.connect( GCallback( valueChanged ), this );
         _verticalSliders.connect( GCallback( valueChanged ), this );
 
-        // Initialize all
-        gtk_range_set_value( GTK_RANGE( _verticalSliders._scale ), 25 );
     }
 
     //____________________________________________________
