@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * This  library is free  software; you can  redistribute it and/or
@@ -27,14 +27,12 @@ namespace Oxygen
 
     //____________________________________________________________________
     TreeViewEngine::TreeViewEngine( Animations* parent ):
-        GenericEngine<TreeViewData>( parent ),
-        _cursorLoaded( false ),
-        _cursor( 0L )
+        GenericEngine<TreeViewData>( parent )
     {}
 
     //____________________________________________________________________
     TreeViewEngine::~TreeViewEngine( void )
-    { if( _cursor ) gdk_cursor_unref( _cursor ); }
+    {}
 
     //____________________________________________________________________
     bool TreeViewEngine::registerWidget( GtkWidget* widget )
@@ -47,6 +45,7 @@ namespace Oxygen
             /* tree lines are rendered by the style, in order to be able to draw them with custom color */
             GtkTreeView* treeView( GTK_TREE_VIEW( widget ) );
             gtk_tree_view_set_enable_tree_lines( treeView, false );
+            gtk_tree_view_set_rules_hint( treeView, true );
 
             GtkWidget* parent( gtk_widget_get_parent( widget ) );
             GtkScrolledWindow* scrolledWindow(0);
@@ -56,17 +55,6 @@ namespace Oxygen
                 !Gtk::gtk_parent_is_shadow_in( parent ) )
             { gtk_scrolled_window_set_shadow_type( scrolledWindow, GTK_SHADOW_IN ); }
 
-            // load cursor if needed
-            if( !_cursorLoaded )
-            {
-                assert( !_cursor );
-                GdkDisplay *display( gtk_widget_get_display( widget ) );
-                _cursor = gdk_cursor_new_from_name( display, "row-resize" );
-                _cursorLoaded = true;
-            }
-
-            // pass cursor to data
-            data().value( widget ).setCursor( _cursor );
 
         }
 
