@@ -45,8 +45,17 @@ namespace Oxygen
 
         protected:
 
+        //! attach style of widget to passed window [recursive]
+        void attachStyle( GtkWidget*, GdkWindow* ) const;
+
+        //! check if widget should have argb helper
+        static bool acceptWidget( GtkWidget* );
+
         //! argb hook
-        static gboolean styleSetHook( GSignalInvocationHint*, guint, const GValue*, gpointer );
+        static gboolean colormapHook( GSignalInvocationHint*, guint, const GValue*, gpointer );
+
+        //! depth adjustment hook
+        static gboolean styleHook( GSignalInvocationHint*, guint, const GValue*, gpointer );
 
         private:
 
@@ -54,7 +63,10 @@ namespace Oxygen
         bool _hooksInitialized;
 
         //! colormap hook
-        Hook _styleSetHook;
+        Hook _colormapHook;
+
+        //! style hook
+        Hook _styleHook;
 
     };
 
