@@ -23,9 +23,63 @@
 
 #include "oxygengtktypenames.h"
 
+#include <vector>
+
 namespace Oxygen
 {
 
+    //_____________________________________________________________________________
+    std::ostream& operator << ( std::ostream& out, const GtkStateFlags& flags )
+    {
+        std::vector<std::string> values;
+        if( !flags ) values.push_back( "normal" );
+        if( flags&GTK_STATE_FLAG_ACTIVE ) values.push_back( "active" );
+        if( flags&GTK_STATE_FLAG_PRELIGHT ) values.push_back( "prelight" );
+        if( flags&GTK_STATE_FLAG_SELECTED  ) values.push_back( "selected" );
+        if( flags&GTK_STATE_FLAG_INSENSITIVE ) values.push_back( "insensitive" );
+        if( flags&GTK_STATE_FLAG_INCONSISTENT ) values.push_back( "inconsistent" );
+        if( flags&GTK_STATE_FLAG_FOCUSED  ) values.push_back( "focused" );
+
+        // print
+        if( values.empty() ) out << "none";
+        else {
+
+            for( unsigned int i=0; i<values.size(); ++i )
+            {
+                if( i==0) out << values[i];
+                else out << "|" << values[i];
+            }
+        }
+
+        return out;
+
+    }
+
+    //_____________________________________________________________________________
+    std::ostream& operator << ( std::ostream& out, const GtkJunctionSides& junctions )
+    {
+        std::vector<std::string> values;
+        if( !junctions ) values.push_back( "none" );
+        if( junctions&GTK_JUNCTION_CORNER_TOPLEFT ) values.push_back( "top-left" );
+        if( junctions&GTK_JUNCTION_CORNER_TOPRIGHT ) values.push_back( "top-right" );
+        if( junctions&GTK_JUNCTION_CORNER_BOTTOMLEFT ) values.push_back( "bottom-left" );
+        if( junctions&GTK_JUNCTION_CORNER_BOTTOMRIGHT ) values.push_back( "bottom-right" );
+
+        // print
+        if( values.empty() ) out << "none";
+        else {
+
+            for( unsigned int i=0; i<values.size(); ++i )
+            {
+                if( i==0) out << values[i];
+                else out << "|" << values[i];
+            }
+        }
+
+        return out;
+
+    }
+
     //_______________________________________________
     typedef Gtk::TypeNames::Entry<GtkStateType> StateMap;
     static const StateMap stateMap[] =
@@ -171,8 +225,26 @@ namespace Oxygen
     { return Gtk::TypeNames::Finder<GtkOrientation>( orientationMap, 2 ).findCss( gtkOrientation ); }
 
     //__________________________________________________________________
-    typedef Gtk::TypeNames::Entry<GtkExpanderStyle> EpanderStyleMap;
-    static const EpanderStyleMap expanderStyleMap[] =
+    typedef Gtk::TypeNames::Entry<GtkBorderStyle> BorderStyleMap;
+    static const BorderStyleMap borderStyleMap[] =
+    {
+        { GTK_BORDER_STYLE_NONE, "none" },
+        { GTK_BORDER_STYLE_SOLID, "solid" },
+        { GTK_BORDER_STYLE_INSET, "inset" },
+        { GTK_BORDER_STYLE_OUTSET, "outset" }
+    };
+
+    //__________________________________________________________________
+    GtkBorderStyle Gtk::TypeNames::matchBorderStyle( const char*  cssBorderStyle )
+    { return Gtk::TypeNames::Finder<GtkBorderStyle>( borderStyleMap, 4 ).findGtk( cssBorderStyle, GTK_BORDER_STYLE_NONE ); }
+
+    //__________________________________________________________________
+    const char*  Gtk::TypeNames::borderStyle( GtkBorderStyle gtkBorderStyle )
+    { return Gtk::TypeNames::Finder<GtkBorderStyle>( borderStyleMap, 4 ).findCss( gtkBorderStyle ); }
+
+    //__________________________________________________________________
+    typedef Gtk::TypeNames::Entry<GtkExpanderStyle> ExpanderStyleMap;
+    static const ExpanderStyleMap expanderStyleMap[] =
     {
         { GTK_EXPANDER_COLLAPSED, "collapsed" },
         { GTK_EXPANDER_SEMI_COLLAPSED, "semi-collapsed" },
@@ -237,28 +309,4 @@ namespace Oxygen
     const char*  Gtk::TypeNames::iconSize( GtkIconSize gtkIconSize )
     { return Gtk::TypeNames::Finder<GtkIconSize>( iconSizeMap, iconSizeMapSize ).findCss( gtkIconSize ); }
 
-    //__________________________________________________________________
-    typedef Gtk::TypeNames::Entry<GFileMonitorEvent> FileMonitorEventMap;
-    static const FileMonitorEventMap fileMonitorEventMap[] =
-    {
-        { G_FILE_MONITOR_EVENT_CHANGED, "changed" },
-        { G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT, "changes done" },
-        { G_FILE_MONITOR_EVENT_DELETED, "deleted" },
-        { G_FILE_MONITOR_EVENT_CREATED, "created" },
-        { G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED, "attribute changed" },
-        { G_FILE_MONITOR_EVENT_PRE_UNMOUNT, "pre_mount" },
-        { G_FILE_MONITOR_EVENT_UNMOUNTED, "unmount" },
-        { G_FILE_MONITOR_EVENT_MOVED, "move" }
-    };
-
-    const int fileMonitorEventMapSize=sizeof(fileMonitorEventMap)/sizeof(fileMonitorEventMap[0]);
-
-    //__________________________________________________________________
-    GFileMonitorEvent Gtk::TypeNames::matchFileMonitorEvent( const char*  monitorEvent )
-    { return Gtk::TypeNames::Finder<GFileMonitorEvent>( fileMonitorEventMap, fileMonitorEventMapSize ).findGtk( monitorEvent, G_FILE_MONITOR_EVENT_CHANGED ); }
-
-    //__________________________________________________________________
-    const char*  Gtk::TypeNames::fileMonitorEvent( GFileMonitorEvent movitorEvent )
-    { return Gtk::TypeNames::Finder<GFileMonitorEvent>( fileMonitorEventMap, fileMonitorEventMapSize ).findCss( movitorEvent ); }
-
 }
