@@ -2,7 +2,7 @@
 #define oxygengtktypenames_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 *
 * based on the Null Theme Engine for Gtk+.
 * Copyright (c) 2008 Robert Staudinger <robert.staudinger@gmail.com>
@@ -25,15 +25,21 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
-#include <gio/gio.h>
 #include <string>
 #include <iostream>
 
 namespace Oxygen
 {
 
+    //! GtkStateFlags streamer
+    std::ostream& operator << ( std::ostream&, const GtkStateFlags& );
+
+    //! GtkJunctionSides streamer
+    std::ostream& operator << ( std::ostream& out, const GtkJunctionSides& );
+
     namespace Gtk
     {
+
         //! css to gtk mapping
         class TypeNames
         {
@@ -65,15 +71,15 @@ namespace Oxygen
             //! tree expander style
             static const char* expanderStyle( GtkExpanderStyle );
 
+            //! tree border style
+            static const char* borderStyle( GtkBorderStyle );
+
             //! Gtk dialogs response IDs
             static const char* response( GtkResponseType );
 
             //! icon size
             static const char* iconSize( GtkIconSize );
 
-            //! file monitor event
-            static const char* fileMonitorEvent( GFileMonitorEvent );
-
             //@}
 
             //__________________________________________
@@ -142,10 +148,10 @@ namespace Oxygen
             static GdkWindowEdge matchWindowEdge	( const char* );
             static GdkWindowTypeHint matchWindowTypeHint( const char* );
             static GtkOrientation matchOrientation( const char* );
+            static GtkBorderStyle	matchBorderStyle( const char* );
             static GtkExpanderStyle	matchExpanderStyle( const char* );
             static GtkResponseType matchResponse( const char* );
             static GtkIconSize matchIconSize( const char* );
-            static GFileMonitorEvent matchFileMonitorEvent( const char* );
 
         };
     }
