@@ -455,12 +455,7 @@ namespace Oxygen
 
         // update icon search path
         // put existing default path in a set
-        PathSet searchPath;
-        gchar** gtkSearchPath;
-        int nElements;
-        gtk_icon_theme_get_search_path( gtk_icon_theme_get_default(), &gtkSearchPath, &nElements );
-        for( int i=0; i<nElements; i++ ) { searchPath.insert( gtkSearchPath[i] ); }
-        g_free( gtkSearchPath );
+        PathSet searchPath( defaultIconSearchPath() );
 
         // add kde's path. Loop is reversed because added path must be prepended.
         for( PathList::const_reverse_iterator iter = _kdeIconPathList.rbegin(); iter != _kdeIconPathList.rend(); ++iter )
@@ -476,12 +471,6 @@ namespace Oxygen
             { gtk_icon_theme_prepend_search_path(gtk_icon_theme_get_default(), path.c_str() ); }
         }
 
-        #if OXYGEN_DEBUG
-        gtk_icon_theme_get_search_path( gtk_icon_theme_get_default(), &gtkSearchPath, &nElements );
-        for( int i=0; i<nElements; i++ )
-        { std::cerr << "Oxygen::QtSettings::loadKdeIcons - icon theme search path: " <<  gtkSearchPath[i] << std::endl; }
-        #endif
-
         // load icon theme and path to gtk
         _iconThemes.clear();
         _kdeIconTheme = _kdeGlobals.getValue( "[Icons]", "Theme", "oxygen" );
@@ -527,6 +516,29 @@ namespace Oxygen
 
     }
 
+    //_________________________________________________________
+    PathSet QtSettings::defaultIconSearchPath( void ) const
+    {
+        PathSet searchPath;
+
+        // load icon theme
+        GtkIconTheme* theme( gtk_icon_theme_get_default() );
+        if( !GTK_IS_ICON_THEME( theme ) ) return searchPath;
+
+        // get default
+        gchar** gtkSearchPath;
+        int nElements;
+
+        gtk_icon_theme_get_search_path( theme, &gtkSearchPath, &nElements );
+        for( int i=0; i<nElements; i++ )
+        { searchPath.insert( gtkSearchPath[i] ); }
+
+        // free
+        g_strfreev( gtkSearchPath );
+
+        return searchPath;
+    }
+
     //_________________________________________________________
     void QtSettings::loadKdePalette( bool forced )
     {
@@ -623,7 +635,7 @@ namespace Oxygen
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Disabled, Palette::WindowText ) ) );
 
         // entries
-        _css.addSection( "GtkEntry, GtkTreeView, GtkTextView, GtkIconView" );
+        _css.addSection( ".view, GtkEntry" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Base ) ) );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Text ) ) );
 
@@ -673,6 +685,16 @@ namespace Oxygen
         _css.addSection( "GtkWindow#gtk-tooltip GtkLabel" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::TooltipText ) ) );
 
+        // rubber band selection (at least for nautilus)
+        // FIXME: is Palette::Selected the proper color? Is 0.35 the proper alpha?
+        _css.addSection( ".view.rubberband,.rubberband" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_COLOR, _palette.color( Palette::Selected ) ) );
+        {
+            std::ostringstream color;
+            color << "  " << GTK_STYLE_PROPERTY_BACKGROUND_COLOR << ": alpha ("<< (std::string)_palette.color( Palette::Selected ) << ", 0.35);";
+            _css.addToCurrentSection( color.str() );
+        }
+
         /*
         this is stupid. Setting the color to all widgets, like above, erases the .info, warning, etc. colors.
         Need to reset them here. This is copied from gtkcssprovider.c
