@@ -1131,13 +1131,6 @@ namespace Oxygen
                 Palette::Group group( (options & Disabled) ? Palette::Disabled : Palette::Active );
                 const ColorUtils::Rgba background( Style::instance().settings().palette().color( group, Palette::Base ) );
 
-                // TODO: remove when bug is fixed upstream
-                #if ENABLE_COMBOBOX_ENTRY_HACK
-                int offset( ( h + 2 - Gtk::gtk_widget_get_allocation( parent ).height )/2 );
-                y += offset;
-                h -= 2*offset;
-                #endif
-
                 if( Gtk::gtk_theming_engine_layout_is_reversed( engine ) )
                 {
 
@@ -2398,7 +2391,7 @@ namespace Oxygen
         Style::instance().shadowHelper().initializeHooks();
 
         // also initialize dbus
-        Oxygen::DBus::instance();
+        Oxygen::DBus::instance().connect();
 
         // initialize argb hooks
         if( Style::instance().settings().argbEnabled() )
